@@ -37,15 +37,14 @@ class BuzzAgent(object):
         self.last_value_dict = dict()
 
     def run(self):
-        if not self.last_run_time:
-            self.last_run_time = time.time() - self.interval
-
         if not self._load_config():
             if not self.alarm_config:
                 # 只有没有配置的情况下才报错
                 return False
 
         now = time.time()
+        if not self.last_run_time:
+            self.last_run_time = now - self.interval
 
         for conf in self.alarm_config:
             stat_name = conf['stat_name']
@@ -66,7 +65,9 @@ class BuzzAgent(object):
                     # 从第二个开始
                     continue
 
+                # 告警的配置项有几个
                 alarm_benchmark = 0
+                # 被触发的配置项有几个
                 alarm_num = 0
 
                 # 命中的，即有效的
@@ -95,15 +96,16 @@ class BuzzAgent(object):
                     # 说明可以计算斜率
                     pre_val = values[k-1]
 
-                    if pre_val > 0:
-                        slope_value = 1.0 * abs(v - pre_val) / pre_val
+                    # v 可能为 None, None 是小于 0 的
+                    if pre_val > 0 and v > 0:
+                        slope_value = 1.0 * (v - pre_val) / pre_val
                     else:
                         slope_value = None
 
                     # logger.debug('slope_value: %s, pre_val: %s, v: %s', slope_value, pre_val, v)
 
                     if slope_value is not None:
-                        code = '%s %s %s' % (slope_value, conf['slope_cmp'], conf['slope_value'])
+                        code = '%s %s %s' % (abs(slope_value), conf['slope_cmp'], conf['slope_value'])
                         if eval(code):
                             alarm_num += 1
 
